@@ -1,10 +1,14 @@
 """
 Set an ip of a domain
 """
+from typing import Union
 import requests
 from .servers import SERVERS
 
-def set_ip(*, domain_name, ip, key):
+def set_ip(*, domain_name : str, ip : str, key : Union[str, int]):
+    """
+    Set an ip of a domain
+    """
     domain = domain_name
     domain = domain.removesuffix("<warp>").split(".")
     tld = domain.pop(-1)
@@ -17,12 +21,12 @@ def set_ip(*, domain_name, ip, key):
     except TimeoutError:
         raise TimeoutError("Server could not be reached.")
     try:
-        assert resp.get("SUCCESS")
+        assert resp.get("success")
     except AssertionError:
-        reason = resp.get("REASON")
+        reason = resp.get("reason")
         if reason == "Domain doesn't exist":
             raise NameError("Domain does not exist")
         if reason == "Failed Authentication":
             raise PermissionError("Failed Authentication")
-        raise ConnectionError(f"There was an error while getting the ip: {reason}")
+        raise Exception(f"There was an error while setting the ip: {reason}")
     return resp["ip"]
